==> phpicalendar-2.1p0.tgz: phpicalendar/languages/dutch.inc.php <==
<?php

// English language include
// For version 2.0 PHP iCalendar
//
// Translation version 1.0 by Lieven Gekiere (Lieven@gekiere.com)
// Translation version 2.0 by John Treffer (john@roem.org)
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= 'Dag';
$lang['l_week'] 			= 'Week';
$lang['l_month'] 			= 'Maand';
$lang['l_year'] 			= 'Jaar';
$lang['l_calendar'] 		= 'Kalender';
$lang['l_next_day'] 		= 'Volgende Dag';
$lang['l_next_month'] 		= 'Volgende Maand';
$lang['l_next_week'] 		= 'Volgende Week';
$lang['l_next_year'] 		= 'Volgend Jaar';
$lang['l_last_day'] 		= 'Vorige Dag';
$lang['l_last_month'] 		= 'Vorige Maand';
$lang['l_last_week'] 		= 'Vorige Week';
$lang['l_last_year'] 		= 'Vorig Jaar';
$lang['l_subscribe'] 		= 'Abonneer';
$lang['l_download'] 		= 'Download';
$lang['l_powered_by'] 		= 'Gemaakt met';
$lang['l_event'] 			= 'Activiteit';
$lang['l_event_start'] 		= 'Start Tijd';
$lang['l_event_end'] 		= 'Eind Tijd';
$lang['l_this_months'] 		= 'Activiteiten deze Maand';
$lang['l_date'] 			= 'Datum';
$lang['l_summary'] 			= 'Overzicht';
$lang['l_all_day'] 			= 'Dagactiviteit';
$lang['l_notes'] 			= 'Opmerkingen';
$lang['l_this_years'] 		= 'Activiteiten dit Jaar';
$lang['l_today'] 			= 'Vandaag';
$lang['l_this_week'] 		= 'Deze Week';
$lang['l_this_month'] 		= 'Deze Maand';
$lang['l_jump'] 			= 'Ga naar';
$lang['l_tomorrows'] 		= 'Activiteiten Morgen';
$lang['l_goday'] 			= 'Ga naar Vandaag';
$lang['l_goweek'] 			= 'Ga naar Deze Week';
$lang['l_gomonth'] 			= 'Ga naar Deze Maand';
$lang['l_goyear'] 			= 'Ga naar Dit Jaar';
$lang['l_search'] 			= 'Zoeken'; // the verb
$lang['l_results'] 			= 'Zoekresultaten';
$lang['l_query'] 			= 'Zoekopdracht'; // will be followed by the search query
$lang['l_no_results'] 		= 'Geen activiteiten gevonden';
$lang['l_goprint'] 			= 'Makkelijk printbaar';
$lang['l_time'] 			= 'Tijd';
$lang['l_summary'] 			= 'Samenvatting';
$lang['l_description'] 		= 'Omschrijving';
$lang['l_this_site_is']		= 'Deze site is';
$lang['l_no_events_day']	= 'Geen activiteiten vandaag.';
$lang['l_no_events_week']	= 'Geen activiteiten deze week.';
$lang['l_no_events_month']	= 'Geen activiteiten deze maand.';
$lang['l_rss_day_date']		= 'H:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_month_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_language']		= 'nl';
$lang['l_search_took']		= 'Zoeken duurde %s seconden';
$lang['l_recurring_event']	= 'Terugkerende activiteit';
$lang['l_exception']		= 'Uitzondering';
$lang['l_no_query']			= 'Geen zoekopdracht gegeven';
$lang['l_preferences']		= 'Voorkeuren';
$lang['l_printer']			= 'Printer';
$lang['l_select_lang']		= 'Selecteer jouw standaard Taal';
$lang['l_select_cal']		= 'Selecteer jouw standaard Kalender';
$lang['l_select_view']		= 'Selecteer jouw standaard View';
$lang['l_select_time']		= 'Selecteer jouw standaard Start Tijd';
$lang['l_select_day']		= 'Selecteer jouw standaard Start Weekdag';
$lang['l_select_style']		= 'Selecteer jouw standaard Stijl';
$lang['l_set_prefs']		= 'Stel voorkeuren in';
$lang['l_completed_date']	= 'Afgewerkt op';
$lang['l_completed']		= 'Afgewerkt';
$lang['l_created']			= 'Gemaakt';
$lang['l_due']				= 'op';
$lang['l_priority']			= 'Prioriteit';
$lang['l_priority_high']	= 'Hoog';
$lang['l_priority_low']		= 'Laag';
$lang['l_priority_medium']	= 'Gemiddeld';
$lang['l_priority_none']	= 'Geen';
$lang['l_status']			= 'Status';
$lang['l_todo']				= 'Af te werken items';
$lang['l_unfinished']		= 'Niet afgewerkt';
$lang['l_prefs_set'] 		= 'Uw voorkeuren zijn bewaard.';
$lang['l_prefs_unset'] 		= 'Voorkeuren gewist. Aanpassingen zijn actief bij de volgende pagina die u laadt.';
$lang['l_unset_prefs'] 		= 'Voorkeuren wissen';
$lang['l_organizer']		= 'Organisator';
$lang['l_attendee']			= 'Aanwezige';
$lang['l_location']			= 'Locatie';
$lang['l_admin_header']		= 'PHP iCalendar Administratie';
$lang['l_username']			= 'Gebruikersnaam';
$lang['l_password']			= 'Wachtwoord';
$lang['l_login']			= 'Login';
$lang['l_invalid_login']	= 'Foutieve gebruikersnaam of wachtwoord.';
$lang['l_addupdate_cal']	= 'Voeg een kalender toe of pas hem aan';
$lang['l_addupdate_desc']	= 'Voeg een kalender toe door een bestand up te loaden. Update een kalender door hem te uploaden met dezelfde naam.';
$lang['l_delete_cal']		= 'Verwijder een kalender';
$lang['l_logout']			= 'Log uit';
$lang['l_cal_file']			= 'Kalenderbestand';
$lang['l_php_error']		= 'PHP foutmelding';
$upload_error_gen_lang		= 'Er was een probleem met uw upload.';
$upload_error_lang[0]		= 'Er was een probleem met uw upload.';
$upload_error_lang[1]		= 'Het bestand dat je probeert up te loaden is te groot.';
$upload_error_lang[2]		= 'Het bestand dat je probeert up te loaden is te groot.';
$upload_error_lang[3]		= 'Het bestand dat je probeert up te loaden is maar gedeeltelijk geuploaded.';
$upload_error_lang[4]		= 'U moet een bestand selecteren om te uploaden.';
$lang['l_upload_error_type'] = 'Enkel .ics bestanden mogen geuploaded worden.';
$lang['l_copy_error']			= 'Kopieren bestand mislukt';
$lang['l_delete_error']			= 'Verwijderen bestand mislukt';
$lang['l_delete_success']		= 'is succesvol verwijderd.';
$lang['l_action_success']		= 'Uw handeling was succesvol.';
$lang['l_submit']				= 'Verzenden';
$lang['l_delete']				= 'Verwijder';
$all_cal_comb_lang			= 'Alle kalenders gecombineerd';

// New for 2.0
$lang['l_legend']			= 'Legenda';
$lang['l_admin_subhead']	= 'Beheer je kalenders via deze pagina';
$lang['l_prefs_subhead']	= 'Bewaart een cookie voor het bezoeken van deze site';
$lang['l_rss_info']			= 'RSS Informatie';
$lang['l_rss_subhead']		= 'Basis RSS feeds beschikbaar voor iedere Kalender';
$lang['l_rss_notenabled']	= 'RSS is niet ingesteld op deze site';

// - navigation
$lang['l_back'] 		= 'Terug';
$lang['l_next'] 		= 'Volgende';
$lang['l_prev'] 		= 'Vorige';
$lang['l_day_view'] 	= 'Dagoverzicht';
$lang['l_week_view'] 	= 'Weekoverzicht';
$lang['l_month_view'] 	= 'Maandoverzicht';
$lang['l_year_view'] 	= 'Jaaroverzicht';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('jaar','jaren');		// for these, put singular
$format_recur_lang['monthly']		= array('maand','maanden');		// and plural forms
$format_recur_lang['weekly']		= array('week','weken');		// these will be %freq%
$format_recur_lang['daily']			= array('dag','dagen');			// in the replacement below
$format_recur_lang['hourly']		= array('uur','uren');
$format_recur_lang['minutely']		= array('minuut','minuten');
$format_recur_lang['secondly']		= array('seconde','seconden');

$format_recur_lang['start']			= 'Iedere %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'tot %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= '%int% maal';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'In de maanden: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'Op datums: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'Op dagen: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Zondag','Maandag','Dinsdag','Woensdag','Donderdag','Vrijdag','Zaterdag');
$daysofweekshort_lang		= array ('Zo','Ma','Di','Wo','Do','Vr','Za');
$daysofweekreallyshort_lang	= array ('Z','M','D','W','D','V','Z');
$monthsofyear_lang			= array ('Januari','Februari','Maart','April','Mei','Juni','Juli','Augustus','September','Oktober','November','December');
$monthsofyearshort_lang		= array ('Jan','Feb','Maa','Apr','Mei','Jun','Jul','Aug','Sep','Okt','Nov','Dec');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'H:i';
$timeFormat_small = 'G:i';

// For date formatting, see note below
$dateFormat_day = '%A, %e %B';
$dateFormat_week = '%e %B';
$dateFormat_week_list = '%a, %e %b';
$dateFormat_week_jump = '%e %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %e %B';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Foutmelding!';
$lang['l_error_window'] 		= 'Er is een fout opgetreden!';
$lang['l_error_calendar'] 		= 'De kalender "%s" werd verwerkt toen de fout optrad.';
$lang['l_error_path'] 			= 'Onmogelijk om de directory te openen: "%s"';
$lang['l_error_back'] 			= 'Gebruik de knop "Vorige" om terug te keren.';
$lang['l_error_remotecal'] 		= 'Deze server blokkeert niet-geaccepteerde kalenders.';
$lang['l_error_restrictedcal'] 	= 'U probeerde toegang te verwerven tot een beveiligde kalender.';
$lang['l_error_invalidcal'] 	= 'Ongeldig kalenderbestand. Probeer een andere kalender aub.';
$lang['l_error_cantopen'] 		= 'Onmogelijk kalender te openen.';
$lang['l_error_cache']			= 'Onmogelijk om naar cache directory te schrijven. Controleer uw configuratie.';

?>

==> phpicalendar-2.31.tgz: phpicalendar/languages/dutch.inc.php <==
<?php

// English language include
// For version 2.0 PHP iCalendar
//
// Translation version 1.0 by Lieven Gekiere (Lieven@gekiere.com)
// Translation version 2.0 by John Treffer (john@roem.org)
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= 'Dag';
$lang['l_week'] 			= 'Week';
$lang['l_month'] 			= 'Maand';
$lang['l_year'] 			= 'Jaar';
$lang['l_calendar'] 		= 'Kalender';
$lang['l_next_day'] 		= 'Volgende Dag';
$lang['l_next_month'] 		= 'Volgende Maand';
$lang['l_next_week'] 		= 'Volgende Week';
$lang['l_next_year'] 		= 'Volgend Jaar';
$lang['l_last_day'] 		= 'Vorige Dag';
$lang['l_last_month'] 		= 'Vorige Maand';
$lang['l_last_week'] 		= 'Vorige Week';
$lang['l_last_year'] 		= 'Vorig Jaar';
$lang['l_subscribe'] 		= 'Abonneer';
$lang['l_download'] 		= 'Download';
$lang['l_powered_by'] 		= 'Gemaakt met';
$lang['l_event'] 			= 'Activiteit';
$lang['l_event_start'] 		= 'Start Tijd';
$lang['l_event_end'] 		= 'Eind Tijd';
$lang['l_this_months'] 		= 'Activiteiten deze Maand';
$lang['l_date'] 			= 'Datum';
$lang['l_summary'] 			= 'Overzicht';
$lang['l_all_day'] 			= 'Dagactiviteit';
$lang['l_notes'] 			= 'Opmerkingen';
$lang['l_this_years'] 		= 'Activiteiten dit Jaar';
$lang['l_today'] 			= 'Vandaag';
$lang['l_this_week'] 		= 'Deze Week';
$lang['l_this_month'] 		= 'Deze Maand';
$lang['l_jump'] 			= 'Ga naar';
$lang['l_tomorrows'] 		= 'Activiteiten Morgen';
$lang['l_goday'] 			= 'Ga naar Vandaag';
$lang['l_goweek'] 			= 'Ga naar Deze Week';
$lang['l_gomonth'] 			= 'Ga naar Deze Maand';
$lang['l_goyear'] 			= 'Ga naar Dit Jaar';
$lang['l_search'] 			= 'Zoeken'; // the verb
$lang['l_results'] 			= 'Zoekresultaten';
$lang['l_pick_multiple'] 	= 'Pick multiple';
$lang['l_query'] 			= 'Zoekopdracht'; // will be followed by the search query
$lang['l_no_results'] 		= 'Geen activiteiten gevonden';
$lang['l_goprint'] 			= 'Makkelijk printbaar';
$lang['l_time'] 			= 'Tijd';
$lang['l_summary'] 			= 'Samenvatting';
$lang['l_description'] 		= 'Omschrijving';
$lang['l_this_site_is']		= 'Deze site is';
$lang['l_no_events_day']	= 'Geen activiteiten vandaag.';
$lang['l_no_events_week']	= 'Geen activiteiten deze week.';
$lang['l_no_events_month']	= 'Geen activiteiten deze maand.';
$lang['l_rss_day_date']		= 'H:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_month_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_language']		= 'nl';
$lang['l_search_took']		= 'Zoeken duurde %s seconden';
$lang['l_recurring_event']	= 'Terugkerende activiteit';
$lang['l_exception']		= 'Uitzondering';
$lang['l_no_query']			= 'Geen zoekopdracht gegeven';
$lang['l_preferences']		= 'Voorkeuren';
$lang['l_printer']			= 'Printer';
$lang['l_select_lang']		= 'Selecteer jouw standaard Taal';
$lang['l_select_cal']		= 'Selecteer jouw standaard Kalender';
$lang['l_select_view']		= 'Selecteer jouw standaard View';
$lang['l_select_time']		= 'Selecteer jouw standaard Start Tijd';
$lang['l_select_day']		= 'Selecteer jouw standaard Start Weekdag';
$lang['l_select_style']		= 'Selecteer jouw standaard Stijl';
$lang['l_set_prefs']		= 'Stel voorkeuren in';
$lang['l_completed_date']	= 'Afgewerkt op';
$lang['l_completed']		= 'Afgewerkt';
$lang['l_created']			= 'Gemaakt';
$lang['l_due']				= 'op';
$lang['l_priority']			= 'Prioriteit';
$lang['l_priority_high']	= 'Hoog';
$lang['l_priority_low']		= 'Laag';
$lang['l_priority_medium']	= 'Gemiddeld';
$lang['l_priority_none']	= 'Geen';
$lang['l_status']			= 'Status';
$lang['l_status_confirmed'] = 'CONFIRMED' ; 
$lang['l_status_cancelled'] = 'CANCELLED'; 
$lang['l_status_tentative'] = 'TENTATIVE'; 
$lang['l_todo']				= 'Af te werken items';
$lang['l_unfinished']		= 'Niet afgewerkt';
$lang['l_prefs_set'] 		= 'Uw voorkeuren zijn bewaard.';
$lang['l_prefs_unset'] 		= 'Voorkeuren gewist. Aanpassingen zijn actief bij de volgende pagina die u laadt.';
$lang['l_unset_prefs'] 		= 'Voorkeuren wissen';
$lang['l_organizer']		= 'Organisator';
$lang['l_attendee']			= 'Aanwezige';
$lang['l_location']			= 'Locatie';
$lang['l_admin_header']		= 'PHP iCalendar Administratie';
$lang['l_username']			= 'Gebruikersnaam';
$lang['l_password']			= 'Wachtwoord';
$lang['l_login']			= 'Login';
$lang['l_invalid_login']	= 'Foutieve gebruikersnaam of wachtwoord.';
$lang['l_addupdate_cal']	= 'Voeg een kalender toe of pas hem aan';
$lang['l_addupdate_desc']	= 'Voeg een kalender toe door een bestand up te loaden. Update een kalender door hem te uploaden met dezelfde naam.';
$lang['l_delete_cal']		= 'Verwijder een kalender';
$lang['l_logout']			= 'Log uit';
$lang['l_cal_file']			= 'Kalenderbestand';
$lang['l_php_error']		= 'PHP foutmelding';
$upload_error_gen_lang		= 'Er was een probleem met uw upload.';
$upload_error_lang[0]		= 'Er was een probleem met uw upload.';
$upload_error_lang[1]		= 'Het bestand dat je probeert up te loaden is te groot.';
$upload_error_lang[2]		= 'Het bestand dat je probeert up te loaden is te groot.';
$upload_error_lang[3]		= 'Het bestand dat je probeert up te loaden is maar gedeeltelijk geuploaded.';
$upload_error_lang[4]		= 'U moet een bestand selecteren om te uploaden.';
$lang['l_upload_error_type'] = 'Enkel .ics bestanden mogen geuploaded worden.';
$lang['l_copy_error']			= 'Kopieren bestand mislukt';
$lang['l_delete_error']			= 'Verwijderen bestand mislukt';
$lang['l_delete_success']		= 'is succesvol verwijderd.';
$lang['l_action_success']		= 'Uw handeling was succesvol.';
$lang['l_submit']				= 'Verzenden';
$lang['l_delete']				= 'Verwijder';
$all_cal_comb_lang			= 'Alle kalenders gecombineerd';

// New for 2.0
$lang['l_legend']			= 'Legenda';
$lang['l_admin_subhead']	= 'Beheer je kalenders via deze pagina';
$lang['l_prefs_subhead']	= 'Bewaart een cookie voor het bezoeken van deze site';
$lang['l_rss_info']			= 'RSS Informatie';
$lang['l_rss_subhead']		= 'Basis RSS feeds beschikbaar voor iedere Kalender';
$lang['l_rss_notenabled']	= 'RSS is niet ingesteld op deze site';

// - navigation
$lang['l_back'] 		= 'Terug';
$lang['l_next'] 		= 'Volgende';
$lang['l_prev'] 		= 'Vorige';
$lang['l_day_view'] 	= 'Dagoverzicht';
$lang['l_week_view'] 	= 'Weekoverzicht';
$lang['l_month_view'] 	= 'Maandoverzicht';
$lang['l_year_view'] 	= 'Jaaroverzicht';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('jaar','jaren');		// for these, put singular
$format_recur_lang['monthly']		= array('maand','maanden');		// and plural forms
$format_recur_lang['weekly']		= array('week','weken');		// these will be %freq%
$format_recur_lang['daily']			= array('dag','dagen');			// in the replacement below
$format_recur_lang['hourly']		= array('uur','uren');
$format_recur_lang['minutely']		= array('minuut','minuten');
$format_recur_lang['secondly']		= array('seconde','seconden');

$format_recur_lang['start']			= 'Iedere %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'tot %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= '%int% maal';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'In de maanden: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'Op datums: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'Op dagen: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Zondag','Maandag','Dinsdag','Woensdag','Donderdag','Vrijdag','Zaterdag');
$daysofweekshort_lang		= array ('Zo','Ma','Di','Wo','Do','Vr','Za');
$daysofweekreallyshort_lang	= array ('Z','M','D','W','D','V','Z');
$monthsofyear_lang			= array ('Januari','Februari','Maart','April','Mei','Juni','Juli','Augustus','September','Oktober','November','December');
$monthsofyearshort_lang		= array ('Jan','Feb','Maa','Apr','Mei','Jun','Jul','Aug','Sep','Okt','Nov','Dec');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'H:i';
$timeFormat_small = 'G:i';

// For date formatting, see note below
$dateFormat_day = '%A, %e %B';
$dateFormat_week = '%e %B';
$dateFormat_week_list = '%a, %e %b';
$dateFormat_week_jump = '%e %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %e %B';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Foutmelding!';
$lang['l_error_window'] 		= 'Er is een fout opgetreden!';
$lang['l_error_calendar'] 		= 'De kalender "%s" werd verwerkt toen de fout optrad.';
$lang['l_error_path'] 			= 'Onmogelijk om de directory te openen: "%s"';
$lang['l_error_back'] 			= 'Gebruik de knop "Vorige" om terug te keren.';
$lang['l_error_remotecal'] 		= 'Deze server blokkeert niet-geaccepteerde kalenders.';
$lang['l_error_restrictedcal'] 	= 'U probeerde toegang te verwerven tot een beveiligde kalender.';
$lang['l_error_invalidcal'] 	= 'Ongeldig kalenderbestand. Probeer een andere kalender aub.';
$lang['l_error_cantopen'] 		= 'Onmogelijk kalender te openen.';
$lang['l_error_cache']			= 'Onmogelijk om naar cache directory te schrijven. Controleer uw configuratie.';

?>
